date: Date of calculation
total_value: Total Value of the Project.
budget_at_completion: Aggregate costs of all of the task
budgets
project_complete: Project Complete based on Earned Value and
total Project Value.
schedule_complete: The difference in Earned Value and Planned
value as a proportion of the Total Value.
planned_value: The amount of the project that is supposed to
have been completed.
earned_value: The amount of the project that is actually
completed
actual_cost: Actual Cost is the actual to-date cost of the
project.
schedule_variance: The amount that the project is ahead or
behind schedule.
cost_variance: How far the task is over or under budget.
cost_performance_index: Relative amount of the variance to
Planned Value.
estimate_at_completion: What the overall project budget will
be if everything else went according to plan.
estimate_to_complete: How much money must be spent from this
point forward, to complete the project.
variance_at_completion: The forecasted cost variance (CV) at
the completion of the project.
to_complete_performance_index: What CPI would be necessary
to finish the project on budget.