Learn R Programming

pmev (version 0.1.2)

ev: Get linearly scaled variable based on optimal bins

Description

Get linearly scaled variable based on optimal bins

Get linearly scaled variable based on optimal bins

Arguments

Public fields

planned_value

(numeric())
Planned value schedule

earned_value

(numeric())
Earned value calculations

Methods

Public methods


Method new()

Usage

ev$new(
  start,
  end,
  progress,
  planned_cost,
  project_value,
  cost_to_date,
  date = today()
)

Arguments

start

Start Date of activity

end

End Date of activity

progress

Proportion between 0 and 1 representing percentage completed for each activity (1 = 100% complete)

planned_cost

The planned costs of each activity

project_value

The total value of the project

cost_to_date

The total amount spent on the project to date

date

Character date "YYYY-MM-DD". Defaults to today.

Returns

A new ev object.


Method plot()

Plots the planned and earned values

Usage

ev$plot()


Method clone()

The objects of this class are cloneable with this method.

Usage

ev$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

Finds outliers and then bands between 0 and 1 on optimal bins of non-outlier data

Examples

Run this code
data(project)
tmp <- ev$new(start = project$start,
                       end = project$end,
                       progress = project$progress,
                       planned_cost = project$planned_cost,
                       project_value = 150000,
                       cost_to_date = 10000,
                       date = "2024-07-03")
plot(tmp)

Run the code above in your browser using DataLab