Learn R Programming

pmev (version 0.1.2)

get_planned_value: Calculate the Planned Value of a Project Schedule to Date

Description

Given a set of project activities start times, end times, progress and costs, this function calculates the Planned Value across the Project Schedule

Usage

get_planned_value(df, project_value)

Arguments

df

A Data Frame of the Project

project_value

The total value of the project